==> rong-ui-react-0.0.1.tgz: package/es/modal/createModal.js <==
var _excluded = ["target"];

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import Modal from './modal';
import ReactDOM from 'react-dom';

var create = function create(options) {
  if (typeof options === 'string') options = {
    content: options
  };

  var _options = options,
      target = _options.target,
      other = _objectWithoutProperties(_options, _excluded);

  var container = target || document.querySelector('#portal-target');
  var modalRef = /*#__PURE__*/React.createRef();

  if (!container) {
    container = document.createElement('div');
    container.id = 'portal-target';
    document.body.appendChild(container);
  }

  if (!other.onConfirm) other.onConfirm = function () {
    this.remove();
  };
  if (!other.onCancel) other.onCancel = function () {
    this.remove();
  };
  if (!other.onClose) other.onClose = function () {
    this.remove();
  };
  other.target = container;
  other.fromInstance = true;
  other.visible = true;
  ReactDOM.render( /*#__PURE__*/React.createElement(Modal, _extends({
    ref: modalRef
  }, other)), container); // ReactDOM.render 不一定是同步的， $dialog直接返回ref，有可能返回的值为null

  return {
    remove: function remove() {
      modalRef.current && modalRef.current.remove();
    },
    querySelector: function querySelector(selectors) {
      return modalRef.current.container.querySelector(selectors);
    }
  };
};

export default create;

==> rong-ui-react-0.0.4.tgz: package/es/modal/createModal.js <==
var _excluded = ["target"];

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import Modal from './modal';
import ReactDOM from 'react-dom';

var create = function create(options) {
  if (typeof options === 'string' || typeof options === 'number') options = {
    content: options
  };

  var _options = options,
      target = _options.target,
      other = _objectWithoutProperties(_options, _excluded);

  var container = target || document.querySelector('#portal-target');
  var modalRef = /*#__PURE__*/React.createRef();

  if (!container) {
    container = document.createElement('div');
    container.id = 'portal-target';
    document.body.appendChild(container);
  }

  if (!other.onConfirm) other.onConfirm = function () {
    this.remove();
  };
  if (!other.onCancel) other.onCancel = function () {
    this.remove();
  };
  if (!other.onClose) other.onClose = function () {
    this.remove();
  };
  other.target = container;
  other.fromInstance = true;
  other.visible = true;
  ReactDOM.render( /*#__PURE__*/React.createElement(Modal, _extends({
    ref: modalRef
  }, other)), container); // ReactDOM.render 不一定是同步的， $dialog直接返回ref，有可能返回的值为null

  return {
    remove: function remove() {
      modalRef.current && modalRef.current.remove();
    },
    querySelector: function querySelector(selectors) {
      return modalRef.current.container.querySelector(selectors);
    }
  };
};

export default create;
